summaryrefslogtreecommitdiff
path: root/framework/source/inc/loadenv/loadenv.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'framework/source/inc/loadenv/loadenv.hxx')
-rw-r--r--framework/source/inc/loadenv/loadenv.hxx4
1 files changed, 2 insertions, 2 deletions
diff --git a/framework/source/inc/loadenv/loadenv.hxx b/framework/source/inc/loadenv/loadenv.hxx
index 126bc7ff0511..b82f0aba027f 100644
--- a/framework/source/inc/loadenv/loadenv.hxx
+++ b/framework/source/inc/loadenv/loadenv.hxx
@@ -143,7 +143,7 @@ private:
*/
sal_Int32 m_nSearchFlags;
/** @short contains all needed informations about the resource,
which should be loaded.
@descr Inside this struct e.g. the URL, its type and filter name,
@@ -241,7 +241,7 @@ public:
points to the resource, which should be loaded.
@param lMediaDescriptor
- contains additional informations for the following load request.
+ contains additional information for the following load request.
@param xBaseFrame
points to the frame which must be used as start point for target search.
@@ -143,7 +143,7 @@ private:
*/
sal_Int32 m_nSearchFlags;
- /** @short contains all needed informations about the resource,
+ /** @short contains all needed information about the resource,
which should be loaded.